@@ -1,7 +1,8 @@
 package Date::Baha::i;
 
+# Package declarations {{{
 use strict;
-use vars qw($VERSION); $VERSION = '0.11';
+use vars qw($VERSION); $VERSION = '0.12';
 use base qw(Exporter);
 use vars qw(@EXPORT @EXPORT_OK);
 @EXPORT = @EXPORT_OK = qw(
@@ -10,28 +11,34 @@ use vars qw(@EXPORT @EXPORT_OK);
     date
     days
     days_of_the_week
+    from_bahai
     holy_days
     months
     next_holy_day
+    to_bahai
     years
 );
 
 use Date::Calc qw(
-    leap_year
     Add_Delta_Days
+    Date_to_Days
     Day_of_Week
+    Day_of_Year
     Delta_Days
     Timezone
+    leap_year
 );
 use Lingua::EN::Numbers::Ordinate;
 use Lingua::Num2Word;
+# }}}
 
 # Set constants {{{
 use constant FACTOR => 19;
+use constant FEBRUARY => 2;
 use constant MARCH => 3;
+use constant SHARAF => 16;
 use constant LAST_START_DAY => 2;   # First day of the fast.
 use constant YEAR_START_DAY => 21;  # Spring equinox.
-use constant FEBRUARY => 2;
 use constant LEAP_START_DAY => 26;  # The intercalary days.
 use constant FIRST_YEAR  => 1844;
 use constant ADJUST_YEAR => 1900;
@@ -56,6 +63,7 @@ use constant CYCLE_YEAR => qw(
     Abha
     Vahid
 );
+
 use constant MONTH_DAY => qw(
     Baha
     Jalal
@@ -78,6 +86,34 @@ use constant MONTH_DAY => qw(
     'Ala
     Ayyam-i-Ha
 );
+
+# NOTE: Trailing 0's are stripped, resulting in incorrect
+# computations if certain decimals are not quoted.
+use constant MONTHS => {
+# Month => [Month num, Date span], # Non-leap year day span
+
+    "Baha"       => [ 0,  '3.21',  '4.08'],  # 80,  98
+    "Jalal"      => [ 1,  '4.09',  '4.27'],  # 99, 117
+    "Jamal"      => [ 2,  '4.28',  '5.16'],  #118, 136
+    "'Azamat"    => [ 3,  '5.17',  '6.04'],  #137, 155
+    "Nur"        => [ 4,  '6.05',  '6.23'],  #156, 174
+    "Rahmat"     => [ 5,  '6.24',  '7.12'],  #175, 193
+    "Kalimat"    => [ 6,  '7.13',  '7.31'],  #194, 212
+    "Kamal"      => [ 7,  '8.01',  '8.19'],  #213, 231
+    "Asma'"      => [ 8,  '8.20',  '9.07'],  #232, 250
+    "'Izzat"     => [ 9,  '9.08',  '9.26'],  #251, 269
+    "Mashiyyat"  => [10,  '9.27', '10.15'],  #270, 288
+    "'Ilm"       => [11, '10.16', '11.03'],  #289, 307
+    "Qudrat"     => [12, '11.04', '11.22'],  #308, 326
+    "Qawl"       => [13, '11.23', '12.11'],  #327, 345
+    "Masa'il"    => [14, '12.12', '12.30'],  #346, 364
+    "Sharaf"     => [15, '12.31',  '1.18'],  #365,  18
+    "Sultan"     => [16,  '1.19',  '2.06'],  # 19,  37
+    "Mulk"       => [17,  '2.07',  '2.25'],  # 38,  56
+    "Ayyam-i-Ha" => [-1,  '2.26',  '3.01'],  # 57,  60
+    "'Ala"       => [18,  '3.02',  '3.20'],  # 61,  79
+};
+
 use constant DOW_NAME => qw(
     Jalal
     Jamal
@@ -90,7 +126,6 @@ use constant DOW_NAME => qw(
 use constant HOLY_DAYS => {
     # Work suspended:
     "Naw Ruz"                   => [ 3, 21],
-    "Days of Ridvan"            => [ 4, 21, 12],
     "First Day of Ridvan"       => [ 4, 21],
     "Ninth Day of Ridvan"       => [ 4, 29],
     "Twelfth Day of Ridvan"     => [ 5,  2],
@@ -102,8 +137,9 @@ use constant HOLY_DAYS => {
     # Work not suspended:
     "Day of the Covenant"       => [11, 26],
     "Ascension of 'Abdu'l-Baha" => [11, 28],
-    "Ayyam-i-Ha"                => [ 2, 25,  4],  # 5 days in leap years
+    "Ayyam-i-Ha"                => [ 2, 26,  4],  # 5 days in leap years
     "The Fast"                  => [ 3,  2, 19],
+    "Days of Ridvan"            => [ 4, 21, 12],
 };
 # }}}
 
@@ -116,75 +152,37 @@ sub days_of_the_week { return DOW_NAME }
 sub holy_days { return HOLY_DAYS }
 # }}}
 
-# date function {{{
-sub date {
+sub date { goto &to_bahai }
+sub to_bahai {  # {{{
     my %args = @_;
-
+    # readability++
     my ($year, $month, $day) = @args{qw(year month day)};
 
+    # Use the system time, if a ymd is not provided.
     unless ($year && $month && $day) {
-        if ($args{use_gmtime}) {
-            ($year, $month, $day) = $args{timestamp}
-                ? (gmtime($args{timestamp}))[5,4,3]
-                : (gmtime)[5,4,3];
-        }
-        else {
-            ($year, $month, $day) = $args{timestamp}
-                ? (localtime($args{timestamp}))[5,4,3]
-                : (localtime)[5,4,3];
-        }
+        $args{epoch} ||= time;
+
+        ($year, $month, $day) = $args{use_gmtime}
+            ? (gmtime $args{epoch})[5,4,3]
+            : (localtime $args{epoch})[5,4,3];
 
         # Fix the year and the month.
         $year += ADJUST_YEAR;
         $month++;
     }
 
-    # This is what will eventually be used in the return.
     my ($bahai_month, $bahai_day);
 
-    # Begin with the first month of the year (at the Spring equinox).
-    my ($m, $d) = (MARCH, YEAR_START_DAY);
+    for (values %{ MONTHS() }) {
+        my ($days, $lower, $upper) = _setup_date_comparison(
+            $year, $month, $day, @$_[1,2]
+        );
 
-    # Found month flag.
-    my $found = 0;
-
-    # Loop through all the official months, less two.
-    for my $n (0 .. FACTOR - 2) {
-        my ($my_y, $my_m, $my_d) = _ninteen_days ($year, $m, $d);
-
-        # Have we found our month?
-        if ($found = _in_month_span (
-                $month, $day, $m, $d, $my_m, $my_d)
-        ) {
-            $bahai_day = _delta_month_days (
-                $m, $d - 1, $year, $month, $day
-            );
-            $bahai_month = $n;
+        if ($days >= $lower && $days <= $upper) {
+            $bahai_month = $_->[0];
+            $bahai_day = $days - $lower;
             last;
         }
-
-        # Increment our date.
-        ($m, $d) = ($my_m, $my_d + 1);
-    }
-
-    # If we haven't found our month, check 'Ala.
-    if (!$found &&
-        ($found = _in_month_span (
-            $month, $day, MARCH, LAST_START_DAY, MARCH, YEAR_START_DAY - 1)
-        )
-    ) { 
-        $bahai_day = _delta_month_days (
-            MARCH, LAST_START_DAY - 1, $year, $month, $day
-        );
-        $bahai_month = FACTOR - 1;
-    }   
-
-    # If we still didn't find a month, it is Ayyam-i-Ha!
-    unless ($found) {
-        $bahai_day = _delta_month_days (
-            FEBRUARY, LEAP_START_DAY - 1, $year, $month, $day
-        );
-        $bahai_month = -1;
     }
 
     # Build the date hash to return.
@@ -195,9 +193,32 @@ sub date {
 }
 # }}}
 
-# as_string function {{{
-# XXX With Lingua::Num2Word, naively assume that we only care about English.
-sub as_string {
+sub from_bahai {  # {{{
+    my %args = @_;
+
+    # Figure out the year.
+    my $year = $args{month} > SHARAF || $args{month} == -1
+        ? $args{year} + FIRST_YEAR
+        : $args{year} + FIRST_YEAR - 1;
+
+    # Reset the month number if we are given Ayyam-i-Ha.
+    $args{month} = 0 if $args{month} == -1;
+
+    # This ugliness actually finds the month and day number.
+    my $day = (MONTHS->{ (MONTH_DAY)[$args{month} - 1] })->[1];
+    (my $month, $day) = split /\./, $day;
+    ($year, $month, $day) = Add_Delta_Days (
+        $year, $month, $day, $args{day} - 1
+    );
+
+    return wantarray
+        ? ($year, $month, $day)
+        : join '/', $year, $month, $day;
+}  # }}}
+
+sub as_string {  # {{{
+    # XXX With Lingua::Num2Word, naively assume that we only care
+    # about English.
     my ($date_hash, %args) = @_;
 
     $args{size}     = 1 unless defined $args{size};
@@ -286,13 +307,9 @@ sub as_string {
     }
 
     return $date;
-}
-# }}}
+}  # }}}
 
-# next_holy_day function {{{
-# NOTE: We are only concerned with the month/day, so the date year
-# is ignored.
-sub next_holy_day {
+sub next_holy_day {  # {{{
     my ($year, $month, $day) = @_;
 
     # Make the month and day a pseudo real number.
@@ -312,71 +329,57 @@ sub next_holy_day {
         }
     }
 
-    # If one was not found, just grad the last date in the list.
+    # If one was not found, just grab the last date in the list.
     $holy_date = $sorted[-1] unless $holy_date;
 
-    return { $inverted{$holy_date} => [ split /\./, $holy_date ] };
-}
-# }}}
+    return wantarray
+        ? ( $inverted{$holy_date} => [ split /\./, $holy_date ] )
+        : "$inverted{$holy_date}: $holy_date";
+}  # }}}
 
 # Helper functions {{{
-# The Baha'i week starts on Saturday.
-sub _day_of_week {
-    my ($y, $m, $d) = @_;
-    my $standard = Day_of_Week ($y, $m, $d);
-    $standard++;
-    return $standard > 6 ? 0 : $standard;
-}
+# Date comparison gymnastics.
+sub _setup_date_comparison {  # {{{
+    my ($y, $m, $d, $s, $e) = @_;
 
-# Compute the number of days between consecutive months.
-# In our case, it's, "How many days are we into this Baha'i month?"
-sub _delta_month_days {
-    my ($m1, $d1, $y2, $m2, $d2) = @_;
-    # If Dec-Jan, get the next year.
-    my $y1 = $m1 == 12 && $m2 == 1 ? $y2 + 1 : $y2;
-    return Delta_Days ($y1, $m1, $d1, $y2, $m2, $d2);
-}
+    my ($start_month, $start_day) = split /\./, $s;
+    my ($end_month, $end_day) = split /\./, $e;
 
-# What month are we in?
-sub _in_month_span {
-    my ($m, $d, $m1, $d1, $m2, $d2) = @_;
-    # If the months are the same, just check the day range.
-    if ($m1 == $m2 && $m == $m1) {
-        return $d >= $d1 && $d <= $d2 ? 1 : 0;
+    my ($start_year, $end_year) = ($y, $y);
+    if ($end_month < $start_month) {
+        if ($m == $start_month) {
+            $end_year++;
+        }
+        elsif ($m == $end_month) {
+            $start_year--;
+        }
     }
-    # The months are different so consider each separately.
-    else {
-        return
-            ($m == $m1 && $d >= $d1)
-            ||
-            ($m == $m2 && $d <= $d2)
-            ? 1 : 0;
-    }
-}
 
-# Return  the standard date ninteen days hence.
-sub _ninteen_days {
-    my ($y, $m, $d) = @_;
-    return Add_Delta_Days($y, $m, $d - 1, FACTOR)
-}
+    return
+        Date_to_Days($y, $m, $d),
+        Date_to_Days($start_year, $start_month, $start_day),
+        Date_to_Days($end_year, $end_month, $end_day);
+}  # }}}
 
-sub _build_date {
+sub _build_date {  # {{{
     my ($year, $month, $day, $new_month, $new_day, %args) = @_;
 
     my %date;
     @date{qw(month day)} = ($new_month, $new_day);
 
-    # Set the day of the week.
-    $date{dow} = _day_of_week ($year, $month, $day);
-    $date{dow_name} = (DOW_NAME)[$date{dow}];
-    $date{dow}++;
+    # Set the day of the week (rotated by 2).
+    $date{dow} = Day_of_Week ($year, $month, $day);
+    $date{dow} += 2;
+    $date{dow} = $date{dow} - 7 if $date{dow} > 7;
+    $date{dow_name} = (DOW_NAME)[$date{dow} - 1];
 
     # Set the day.
-    $date{day_name} = (MONTH_DAY)[$date{day} - 1];
+    $date{day_name} = (MONTH_DAY)[$date{day}];
+    $date{day}++;
 
     # Set the the month.
     $date{month_name} = (MONTH_DAY)[$date{month}];
-    # Fix the month number, unless we are in Ayyam-i-ha.
+    # Fix the month number, unless we are in Ayyam-i-Ha.
     $date{month}++ unless $date{month} == -1;
 
     # Set the year.
@@ -413,36 +416,32 @@ sub _build_date {
         if exists $inverted{$m_d};
 
     return wantarray ? %date : as_string (\%date, %args);
-}
+}  # }}}
 
-sub _invert_holy_days {
+sub _invert_holy_days {  # {{{
     my $year = shift || (localtime)[5] + ADJUST_YEAR;
-    my $h = HOLY_DAYS;
 
-    my %expanded;
+    my %inverted;
 
-    while (my ($name, $dates) = each %$h) {
+    while (my ($name, $dates) = each %{ HOLY_DAYS() }) {
         # Pre-pad the day number with a zero.
-        $dates->[1] = sprintf '%02d', $dates->[1];
-
-        $expanded{"$dates->[0].$dates->[1]"} = $name;
+        $inverted{ sprintf '%d.%02d', @$dates[0,1] } = $name;
 
         # Does this date contain a day span?
         if (@$dates == 3) {
             # Increment the Ayyam-i-Ha day if we are in a leap year.
-            $dates->[2]++ if $name eq 'Ayyam-i-ha' && leap_year ($year);
+            $dates->[2]++ if $name eq 'Ayyam-i-Ha' && leap_year ($year);
 
             for (1 .. $dates->[2] - 1) {
-                # Pre-pad the day number with a zero.
                 (undef, my $month, my $day) = Add_Delta_Days($year, @$dates[0,1], $_);
-                $day = sprintf '%02d', $day;
-                $expanded{"$month.$day"} = $name;
+                # Pre-pad the day number with a zero.
+                $inverted{ sprintf '%d.%02d', $month, $day} = $name;
             }
         }
     }
 
-    return %expanded;
-}
+    return %inverted;
+}  # }}}
 # }}}
 
 1;
@@ -456,32 +455,55 @@ Date::Baha::i - Compute the numeric and named Baha'i date.
 
   use Date::Baha'i;
 
-  %bahai_date = date ();
-  %bahai_date = date (timestamp => time);
-  $bahai_date = date (
+  $bahai_date = to_bahai ();
+  $bahai_date = to_bahai (epoch => time);
+  $bahai_date = to_bahai (
       year  => $year,
       month => $month,
       day   => $day,
   );
 
-  $bahai_date = as_string (\%bahai_date);
+  %bahai_date = to_bahai ();
+  %bahai_date = to_bahai (epoch => time);
+  %bahai_date = to_bahai (
+      year  => $year,
+      month => $month,
+      day   => $day,
+  );
+
+  ($year, $month, $day) = from_bahai (
+      year  => $bahai_year,
+      month => $bahai_month,
+      day   => $bahai_day,
+  );
+  $date = from_bahai (
+      year  => $bahai_year,
+      month => $bahai_month,
+      day   => $bahai_day,
+  );
 
   %holy_day = next_holy_day ($year, $month, $day);
+  $holy_day = next_holy_day ($year, $month, $day);
 
-  @ret = cycles ();
-  @ret = years ();
-  @ret = months ();
-  @ret = days ();
-  @ret = days_of_the_week ();
-  @ret = holy_days ();
+  @cycles = cycles ();
+  @years = years ();
+  @months = months ();
+  @days = days ();
+  @days_of_the_week = days_of_the_week ();
+  %holy_days = holy_days ();
 
 =head1 ABSTRACT
 
 This package outputs a (numeric and named) Baha'i date from a standard 
-system time stamp or year, month, day triple.
+epoch time stamp or year, month, day triple.
 
 =head1 DESCRIPTION
 
+This package renders the Baha'i date from two standard date formats -
+epoch time and the Gregorian year/month/day triple.  It is not a date
+arithmetic calculator or two-way converter.  It simply takes a
+standard date and converts it to the Baha'i representation.
+
 The Baha'i year is based on the solar year of 365 days, five hours and
 some fifty minutes. Each year is divided into nineteen months of 
 nineteen days each with four Intercalary Days (five in a leap year), 
@@ -595,9 +617,7 @@ work is to be suspended.
 
 * Ridvan
 
-  First Day   - 21 April
-  Ninth Day   - 29 April
-  Twelfth Day -  2 May
+First day - 21 April; Ninth day - 29 April; Twelfth day - 2 May
 
 The Ridvan (pronouced "riz-wan") festival commemorates the first 
 public declaration by Baha'u'llah of His Station and mission (in 
@@ -622,7 +642,8 @@ Commemorates the date in 1819 when the Bab was born in Shiraz, Iran
 
 * Birth of Baha'u'llah - 12 November
 
-Commemorates the date in 1817 when Baha'u'llah was born in Tihran, Iran
+Commemorates the date in 1817 when Baha'u'llah was born in Tihran, 
+Iran
 
 - Work does not have to cease on these Holy Days:
 
@@ -695,37 +716,81 @@ L<http://www.moonwise.co.uk/year/159bahai.htm>
 
 =head1 EXPORTED FUNCTIONS
 
-=head2 date
+=head2 to_bahai
 
-  %bahai_date = date (
-      timestamp  => $secs_since_1970,
+  # Return a hash in array context.
+  %bahai_date = to_bahai ();
+  %bahai_date = to_bahai (
+      epoch => time,
       use_gmtime => $use_gmtime,
       %args,
-  )
+  );
+  %bahai_date = to_bahai (
+      year  => $year,
+      month => $month,
+      day   => $day,
+      %args,
+  );
 
-This function returns a hash of the Baha'i date names and numbers from
-a system or user provided time () stamp.  Also, this function can be
-forced to use gmtime instead of localtime (the default).  The extra 
-arguments are used for the as_string () function, detailed below.
+  # Return a string in scalar context.
+  $bahai_date = to_bahai ();
+  $bahai_date = to_bahai (
+      epoch => time,
+      use_gmtime => $use_gmtime,
+      %args,
+  );
+  $bahai_date = to_bahai (
+      year  => $year,
+      month => $month,
+      day   => $day,
+      %args,
+  );
+
+This function returns either a string or a hash of the Baha'i date 
+names and numbers from either epoch seconds or a year, month, day 
+triple.
+
+If using epoch seconds, this function can be forced to use gmtime 
+instead of localtime.  If neither a epoch or ymd triple are given, 
+the system localtime (or gmtime) are used as a default.
+
+The extra arguments are most handy, and used by the as_string 
+function, detailed below.
 
 In a scalar context, this function returns a string sentence with the 
-numeric and named Baha'i date.  In an array context, it returns a hash
-with the following keys:
+numeric and/or named Baha'i date.  In an array context, it returns a 
+hash with the following keys:
 
-  kull_i_shay
-  cycle
-  cycle_name
-  cycle_year
-  year
-  year_name
-  month
-  month_name
-  day
-  day_name
-  dow
-  dow_name
-  timezone
-  holy_day
+  kull_i_shay,
+  cycle, cycle_name, cycle_year,
+  year, year_name,
+  month, month_name,
+  day, day_name,
+  dow, dow_name,
+  timezone, and
+  holy_day, if there is one.
+
+=head2 from_bahai
+
+  # Return a ymd triple in array context.
+  ($year, $month, $day) = from_bahai (
+      year  => $bahai_year,
+      month => $bahai_month,
+      day   => $bahai_day,
+  );
+
+  # Return a y/m/d string in scalar context.
+  $date = from_bahai (
+      year  => $bahai_year,
+      month => $bahai_month,
+      day   => $bahai_day,
+  );
+
+This function returns either a string or a list of the standard date 
+from a year, month, day triple of the Baha'i date.
+
+* Currently, this only supports the Baha'i year, month and day.  The
+Baha'i cycle and Kull-i-Shay are coming soon, to a theatre near you...
 
 =head2 as_string
 
@@ -755,7 +820,7 @@ alphanumeric representations on or off.  The defaults are as follows:
 Thus, "long non-numeric alpha without the timezone" is the default 
 representation.
 
-Here are some handy examples:
+Here are some handy examples (newlines added for readability):
 
   short numeric:
   7, 1/1/159
@@ -764,10 +829,13 @@ Here are some handy examples:
   7, 1/1/159, -6
 
   long numeric:
-  7th day of the week, 1st day of the 1st month, year 159, 7th year of the 9th vahid of the 1st kull-i-shay, holy day: Naw Ruz
+  7th day of the week, 1st day of the 1st month, year 159,
+  7th year of the 9th vahid of the 1st kull-i-shay, holy day: Naw Ruz
 
   long numeric with TZ:
-  7th day of the week, 1st day of the 1st month, year 159, 7th year of the 9th vahid of the 1st kull-i-shay, TZ -6h, holy day: Naw Ruz
+  7th day of the week, 1st day of the 1st month, year 159,
+  7th year of the 9th vahid of the 1st kull-i-shay, TZ -6h,
+  holy day: Naw Ruz
 
   short alpha:
   Istiqlal, Baha of Baha, Abad of Baha
@@ -776,73 +844,88 @@ Here are some handy examples:
   Istiqlal, Baha of Baha, Abad of Baha, TZ -6h
 
   long alpha:
-  week day Istiqlal, day Baha of month Baha, year one hundred fifty nine of year Abad of the vahid Baha of the 1st kull-i-shay, holy day: Naw Ruz
+  week day Istiqlal, day Baha of month Baha,
+  year one hundred fifty nine of year Abad of the vahid Baha of the
+  1st kull-i-shay, holy day: Naw Ruz
 
   long alpha with TZ:
-  week day Istiqlal, day Baha of month Baha, year one hundred fifty nine of year Abad of the vahid Baha of the 1st kull-i-shay, with timezone offset of negative six hours, holy day: Naw Ruz
+  week day Istiqlal, day Baha of month Baha,
+  year one hundred fifty nine of year Abad of the vahid Baha of the
+  1st kull-i-shay, with timezone offset of negative six hours,
+  holy day: Naw Ruz
 
   short alpha-numeric:
   Istiqlal (7), Baha (1) of Baha (1), year 159, Abad (7) of Baha (9)
 
   short alpha-numeric with TZ:
-  Istiqlal (7), Baha (1) of Baha (1), year 159, Abad (7) of Baha (9), TZ -6h
+  Istiqlal (7), Baha (1) of Baha (1), year 159, Abad (7) of Baha (9),
+  TZ -6h
 
   long alpha-numeric:
-  7th week day Istiqlal, 1st day Baha of the 1st month Baha, year one hundred fifty nine (159), 7th year Abad of the 9th vahid Baha of the 1st kull-i-shay, holy day: Naw Ruz
+  7th week day Istiqlal, 1st day Baha of the 1st month Baha,
+  year one hundred fifty nine (159), 7th year Abad of the
+  9th vahid Baha of the 1st kull-i-shay, holy day: Naw Ruz
 
   long alpha-numeric with TZ:
-  7th week day Istiqlal, 1st day Baha of the 1st month Baha, year one hundred fifty nine (159), 7th year Abad of the 9th vahid Baha of the 1st kull-i-shay, with timezone offset of negative six hours, holy day: Naw Ruz
+  7th week day Istiqlal, 1st day Baha of the 1st month Baha,
+  year one hundred fifty nine (159), 7th year Abad of the
+  9th vahid Baha of the 1st kull-i-shay,
+  with timezone offset of negative six hours, holy day: Naw Ruz
 
 =head2 next_holy_day
 
-  %holy_day = next_holy_day ($year, $month, $day)
+  %holy_day = next_holy_day ($year, $month, $day);
+  $holy_day = next_holy_day ($year, $month, $day);
 
-This function returns the first holy day after the provided date triple.
+This function returns the first holy day after the provided date
+triple as either a hash (in array context) or a string (in scalar 
+context).
 
-The return is a hash reference with a single key (the name of the
-holy day) and an two element array reference of [month, day] as the 
-value.
+In array context, a hash with a single key (the name of the holy day)
+and a two or three element array reference of [month, day, duration]
+as the value.
 
 =head2 cycles
 
   @cycles = cycles ();
 
-Return the 19 cycle names as an array.
+This function returns the 19 cycle names as an array.
 
 =head2 years
 
   @years = years ();
 
-Return the 19 year names as an array.
+This function returns the 19 year names as an array.
 
 =head2 months
 
   @months = months ();
 
-Return the 19 month names as an array, along with the intercalary days
-("Ayyam-i-Ha") as the last element.
+This function returns the 19 month names as an array, along with the 
+intercalary days (Ayyam-i-Ha) as the last element.
 
 =head2 days
 
   @days = days ();
 
-Return the 19 day names as an array.
+This function returns the 19 day names as an array.
 
 =head2 days_of_the_week
 
   @days = days_of_the_week ();
 
-Return the 7 day-of-the-week names as an array.
+This function returns the 7 day-of-the-week names as an array.
 
 =head2 holy_days
 
-  @days = holy_days ();
+  %days = holy_days ();
 
-Return the holy days as a hash where the keys are the holy day names 
-and the values are array references.  These array references are 
-composed of two or three elements, where the first is the month, the 
-second is the day, and the third is the (optional) number of days 
-observed.  These dates are currently in standard (non-Baha'i) format.
+This function returns the holy days as a hash, where the keys are 
+the holy day names and the values are array references.  These array 
+references are composed of two or three elements, where the first is 
+the month, the second is the day, and the third is the (optional) 
+number of days observed.  These dates are saved in standard 
+(non-Baha'i) format.
 
 =head1 DEPENDENCIES
 
@@ -854,13 +937,15 @@ L<Lingua::Num2Word>
 
 =head1 TO DO
 
-Convert to standard dates and Unix time stamps from Baha'i dates.
+Factor out the fugly _invert_holy_days function.
+
+Make the test suite test every possible date over two years, 
+including a leap year.
 
 Optionally output unicode.
 
 Base the date computation on the time of day (the Baha'i day begins at 
-Sunset) - and the location longitude/latitude.  Yes, that would be 
-with Astro::Sunrise::sunset ().
+Sunset) - and the location longitude/latitude.
 
 Overload localtime and gmtime, just to be cool?
 
@@ -868,8 +953,28 @@ Overload localtime and gmtime, just to be cool?
 
 Hi Kirsten  : )
 
+=head1 DISCLAIMER
+
+I have no designs or intentions to be compatible with other date and 
+time representations (such as ICal or DateTime).  That is for those 
+external packages and the people who care to do the ultra-simple 
+conversions.
+
+This package is simple from the outside and requires only that which 
+is necessary to represent the Baha'i date.  That is, you give it a 
+date, and it returns the Baha'i representation.
+
+(Having said that, please see the TO DO section about wanting to do
+two-way conversions.)
+
 =head1 REFERENCES
 
+L<http://www.projectpluto.com/calendar.htm#bahai>
+
+L<http://www.bahaindex.com/calendar.html>
+
+L<http://www.moonwise.co.uk/year/159bahai.htm>
+
 L<http://www.perl.com/pub/a/2003/03/13/datetime.html>
 
 =head1 AUTHOR
